/*
**-----------------------------------------------------------------------------
**  tsld - temperature sensor logger daemon
**  Copyright (c) 2004  John Clarke <johnc+tsld@kirriwa.net>
**-----------------------------------------------------------------------------
**  $Id: tsld.h,v 1.1 2005/01/17 11:38:34 johnc Exp $
**-----------------------------------------------------------------------------
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**  
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**  
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
**-----------------------------------------------------------------------------
*/

#ifndef _TSLD_H
#define _TSLD_H

/*----------------------------------------------------------------------------*/

#include "config.h"

/*----------------------------------------------------------------------------*/

#include <ctype.h>
#include <errno.h>
#include <grp.h>
#include <limits.h>
#include <pwd.h>
#include <signal.h>
#include <stdio.h>
#include <sys/ioctl.h>
#include <sys/stat.h>
#include <sys/types.h>
#include <termios.h>
#include <time.h>

#ifdef HAVE_RRDTOOL
    #include <rrd.h>
#endif

#ifdef STDC_HEADERS
    #include <stdarg.h>
    #include <stdlib.h>
    #include <string.h>
#else
    #include <varargs.h>
#endif

#ifdef TM_IN_SYS_TIME
    #include <sys/time.h>
#endif

#ifdef HAVE_UNISTD_H
    #include <unistd.h>
#endif

#if HAVE_SYSLOG
    #include <syslog.h>
#endif

/*----------------------------------------------------------------------------*/

#define FALSE           (0 != 0)
#define TRUE            (0 == 0)
#define lengthof(x)     (sizeof(x) / sizeof(x[0]))

/*----------------------------------------------------------------------------*/

#define MAX_SENSORS         4
#define MIN_SAMPLE_PERIOD   5       /* seconds */
#define SECS_PER_DAY        (24 * 60 * 60)

/*----------------------------------------------------------------------------*/

typedef enum
{
    NotPresent,
    Silent,
    Alive
} SensorState;

/*----------------------------------------------------------------------------*/

FILE *SerialPort;                   /* stream handle for serial port */
FILE *LogFile;                      /* stream handle for log file */
const char *LogDirectory;           /* name of log directory (from -l switch) */
char *LogFilename;                  /* name of log file (from -f switch or from -l with current date appended */
int Debug;                          /* debug level */
char const *Id;                     /* Id (from -i switch) */
int LogDay;                         /* day log file was opened */

/*----------------------------------------------------------------------------*/

struct termios SavedTerminalAttributes;  /* saves serial port settings for restoration on exit */

#endif
