/*
**-----------------------------------------------------------------------------
**  tsld - temperature sensor logger daemon
**  Copyright (c) 2004  John Clarke <johnc+tsld@kirriwa.net>
**-----------------------------------------------------------------------------
**  $Id: utils.h,v 1.1 2005/01/17 11:38:34 johnc Exp $
**-----------------------------------------------------------------------------
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**  
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**  
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
**-----------------------------------------------------------------------------
*/

#ifndef _UTILS_H
#define _UTILS_H

#include "tsld.h"

/*----------------------------------------------------------------------------*/

int SigHupReceived;                 /* flag to indicate HUP signal */
int SigUsr1Received;                /* flag to indicate USR1 signal */

/*----------------------------------------------------------------------------*/

/* print a message either to the given stream or to syslog with the given level */
void Message(FILE *Stream, int Level, char const * Format, ...);

/* called on exit to close files and restore serial port settings */
 void CleanupAndExit(void);

/* wrapper around malloc with error checking */
void *Malloc(size_t Size);

/* opens a file */
FILE *Open(char const * Filename, const char *Mode);

/* check if Dir exists */
int DirExists(char const *Dir);

/* close and reopen the log file */
void ReopenLogFile(void);

/* writes the current time to the log file */
void LogTime(const time_t Time);

/* opens the serial port and configures it to talk to the sensor */
void OpenSerialPort(char const * Device);

/* receive a line of text from the sensor */
void ReadSerialPort(char *Buffer, int BufferSize);

/* reset the sensor by lowering and raising DTR */
void ResetSensor(void);

/* gets the uid associated with the given name */
uid_t GetUid(const char *Username);

/* gets the gid associated with the given name */
uid_t GetGid(const char *Groupname);

/* installs the signal handlers */
void SetupSignalHandlers(void);
#endif
